@@ -14,6 +14,7 @@ installed.
 """
 
 import os
+import re
 import sys
 import socket
 import optparse
@@ -30,7 +31,7 @@ except ImportError:
     pygments = None
 
 
-__version__ = "0.0.3"
+__version__ = "0.0.5a"
 
 
 class MyRequestHandler(BaseHTTPServer.BaseHTTPRequestHandler):
@@ -56,6 +57,8 @@ class MyRequestHandler(BaseHTTPServer.BaseHTTPRequestHandler):
             self.send_error(404, "File not found") # no hacking!
         elif self.path.endswith('.png'):
             return self.handle_image(self.translate_path(), 'image/png')
+        elif self.path.endswith('.jpg'):
+            return self.handle_image(self.translate_path(), 'image/jpeg')
         elif self.path.endswith('.txt') or self.path.endswith('.rst'):
             return self.handle_rest_file(self.translate_path())
         else:
@@ -74,7 +77,7 @@ class MyRequestHandler(BaseHTTPServer.BaseHTTPRequestHandler):
             self.send_error(404, "File not found")
         else:
             self.send_response(200)
-            self.send_header("Content-type", ctype)
+            self.send_header("Content-Type", ctype)
             self.send_header("Content-Length", str(len(data)))
             self.end_headers()
             return data
@@ -89,7 +92,7 @@ class MyRequestHandler(BaseHTTPServer.BaseHTTPRequestHandler):
             if isinstance(html, unicode):
                 html = html.encode('UTF-8')
             self.send_response(200)
-            self.send_header("Content-type", "text/html; charset=UTF-8")
+            self.send_header("Content-Type", "text/html; charset=UTF-8")
             self.send_header("Content-Length", str(len(html)))
             self.end_headers()
             return html
@@ -110,7 +113,7 @@ class MyRequestHandler(BaseHTTPServer.BaseHTTPRequestHandler):
         if isinstance(html, unicode):
             html = html.encode('UTF-8')
         self.send_response(200)
-        self.send_header("Content-type", "text/html; charset=UTF-8")
+        self.send_header("Content-Type", "text/html; charset=UTF-8")
         self.send_header("Content-Length", str(len(html)))
         self.end_headers()
         return html
@@ -207,7 +210,21 @@ class SyntaxHighlightingHTMLTranslator(docutils.writers.html4css1.HTMLTranslator
                                                           noclasses=True)
             self.body.append(pygments.highlight(text, lexer, formatter))
         else:
-            docutils.writers.html4css1.HTMLTranslator.visit_Text(self, node)
+            text = node.astext()
+            encoded = self.encode(text)
+            if self.in_mailto and self.settings.cloak_email_addresses:
+                encoded = self.cloak_email(encoded)
+            self.body.append(encoded)
+
+    def encode(self, text):
+        encoded = docutils.writers.html4css1.HTMLTranslator.encode(self, text)
+        encoded = self.link_local_files(encoded)
+        return encoded
+
+    def link_local_files(self, text):
+        """Replace filenames with hyperlinks."""
+        text = re.sub("([-_a-zA-Z0-9]+[.]txt)", r'<a href="\1">\1</a>', text)
+        return text
 
 
 def parse_address(addr):
